@@ -157,7 +157,7 @@ namespace Banshee
             return null;
         }
         
-        public static string ConvertSongName(Uri uri, string newext)
+        public static Uri ConvertSongName(Uri uri, string newext)
         {
             string filename = uri.LocalPath;
             
@@ -165,7 +165,8 @@ namespace Banshee
             string dir = Path.GetDirectoryName(path);
             string file = Path.GetFileNameWithoutExtension(filename);
             
-            return dir + Path.DirectorySeparatorChar + ".banshee-ipod-" + file + "." + newext;
+            return PathUtil.PathToFileUri(dir + Path.DirectorySeparatorChar 
+                + ".banshee-ipod-" + file + "." + newext);
         }
     }
     
@@ -176,8 +177,6 @@ namespace Banshee
         private ArrayList updateTracks;
         private ArrayList removeTracks;
         
-        private ProgressDialog progress;
-        
         private Hashtable copyFiles;
         
         public event EventHandler SyncStarted;
@@ -189,6 +188,7 @@ namespace Banshee
         {
             this.device = device;
             user_event = new ActiveUserEvent(Catalog.GetString("Syncing iPod"));
+            user_event.Icon = Gdk.Pixbuf.LoadFromResource(IpodMisc.GetIconString(device) + "-24.png");
             
             encodeProfile = PipelineProfile.GetConfiguredProfile("Ipod", "mp3,aac,mp4,m4a,m4p");
         }
@@ -202,21 +202,26 @@ namespace Banshee
         
         public void StartSync()
         {
+            EmitSyncStarted();
             EncodeFiles();
         }
         
         private void EmitSyncStarted()
         {
-            EventHandler handler = SyncStarted;
-            if(handler != null)
-                handler(this, new EventArgs());
+            Core.ProxyToMainThread(delegate {
+                EventHandler handler = SyncStarted;
+                if(handler != null)
+                    handler(this, new EventArgs());
+            });
         }
 
         private void EmitSyncCompleted()
         {
-            EventHandler handler = SyncCompleted;
-            if(handler != null)
-                handler(this, new EventArgs());
+            Core.ProxyToMainThread(delegate {
+                EventHandler handler = SyncCompleted;
+                if(handler != null)
+                    handler(this, new EventArgs());
+            });
         }
         
         private bool ExistsOnIpod(Song[] songs, TrackInfo libTrack)
@@ -285,15 +290,14 @@ namespace Banshee
                         continue;
                     }
 
-                    filename = IpodCore.ConvertSongName(libTrack.Uri, encodeProfile.Extension);
-                    Uri uri = new Uri(filename);
-                    
+                    Uri uri = IpodCore.ConvertSongName(libTrack.Uri, encodeProfile.Extension);
                     copyFiles.Add(song, uri);
                     
                     if(fet == null) {
                         fet = new FileEncodeAction(encodeProfile);
                         fet.FileEncodeComplete += OnFileEncodeComplete;
                         fet.Finished += OnFileEncodeBatchFinished;
+                        fet.Canceled += OnFileEncodeCanceled;
                     }
                         
                     fet.AddTrack(libTrack.Uri, uri);
@@ -304,6 +308,7 @@ namespace Banshee
                     }
                 }
             }
+            
             if(fet != null) {
                 fet.Run();
             } else {
@@ -311,6 +316,13 @@ namespace Banshee
             }
         }
         
+        private bool canceled = false;
+        
+        private void OnFileEncodeCanceled(object o, EventArgs args)
+        {
+            canceled = true;
+        }
+        
         private void OnFileEncodeComplete(object o, FileEncodeCompleteArgs args)
         {
             foreach(Song song in copyFiles.Keys) {
@@ -322,7 +334,12 @@ namespace Banshee
         
         private void OnFileEncodeBatchFinished(object o, EventArgs args)
         {
-            SyncIpod();
+            if(!canceled) {
+                SyncIpod();
+            } else {
+                user_event.Dispose();
+                EmitSyncCompleted();
+            }
         }
         
         private void SyncIpod()
@@ -363,13 +380,11 @@ namespace Banshee
         {
             device.SongDatabase.SaveStarted += delegate(object o, EventArgs args) 
             {
-                EmitSyncStarted();
                 user_event.Message = "Preparing to sync...";
             };
             
             device.SongDatabase.SaveEnded += delegate(object o, EventArgs args)
             {
-                EmitSyncCompleted();
                 user_event.Dispose();
             };
             
@@ -385,6 +400,7 @@ namespace Banshee
             };
             
             device.SongDatabase.Save();
+            EmitSyncCompleted();
         }    
     }
     
@@ -477,5 +493,22 @@ namespace Banshee
         {
            return (double)device.VolumeUsed / (double)device.VolumeSize;
         }
+        
+        public static string GetIconString(Device device)
+        {
+            switch(device.Model) {
+                case DeviceModel.Color:
+                case DeviceModel.ColorU2:
+                case DeviceModel.NanoWhite:
+                case DeviceModel.NanoBlack:
+                case DeviceModel.VideoWhite:
+                case DeviceModel.VideoBlack:
+                    return "ipod-color";
+                case DeviceModel.Shuffle:
+                    return "ipod-shuffle";
+                default:
+                    return "ipod-regular";
+            }
+        }
     }
 }
