@@ -60,11 +60,35 @@ namespace Banshee
         public void ReloadDatabase()
         {
             string libraryLocation = Location;
-
-            if(!Directory.Exists(libraryLocation))
-                Directory.CreateDirectory(libraryLocation);
             
-            Db = new Database("Library", libraryLocation + "/.banshee.db");
+            string db_file = Path.Combine(Paths.ApplicationData, "banshee.db");
+            string olddb_file = libraryLocation + Path.DirectorySeparatorChar + ".banshee.db";
+
+            try {
+                if(!Directory.Exists(libraryLocation)) {
+                    Directory.CreateDirectory(libraryLocation);
+                }
+            } catch(Exception) {
+                Console.WriteLine("Could not create Library directory: " + libraryLocation);
+            }
+            
+            if(!Directory.Exists(Paths.ApplicationData)) {
+                Directory.CreateDirectory(Paths.ApplicationData);
+            }
+            
+            if(!File.Exists(db_file) && File.Exists(olddb_file)) {
+                Console.WriteLine("Copied old library to new location");
+                
+                File.Copy(olddb_file, db_file);
+                
+                try {
+                    File.Delete(olddb_file);
+                } catch(Exception) {
+                    Console.WriteLine("Could not remove old library");
+                }
+            }
+            
+            Db = new Database("Library",  db_file);
         }
         
         public void ReloadLibrary()
