@@ -92,12 +92,8 @@ namespace Banshee
 			try {
 				Run();
 			} catch(Exception e) {
-				DebugLog.Add(String.Format(Catalog.GetString(
-					"{0} threw an unhandled exception: ending " + 
-					"transaction safely: {1} ({2})"),
-					GetType().ToString(),
-					e.GetType().ToString(), 
-					e.Message));
+				Core.Log.PushDebug(Catalog.GetString("Unhandled Exception, ending IO Transaction safely"),
+				    String.Format("{0} threw {1} ({2})", GetType().ToString(), e.GetType().ToString(), e.Message));
 			}
 			
 			Finish(this);
@@ -122,11 +118,11 @@ namespace Banshee
 					ExecutingThread.Abort();
 				} catch(Exception) {}
 				
-				DebugLog.Add("Forcefully canceled LibraryTransaction");
+				Core.Log.PushDebug("Forcefully canceled LibraryTransaction", GetType().ToString());
 				return;
 			}
 			
-			DebugLog.Add("Peacefully canceled LibraryTransaction");
+			Core.Log.PushDebug("Peacefully canceled LibraryTransaction", GetType().ToString());
 		}
 		
 		protected void UpdateAverageDuration(DateTime start)
@@ -616,9 +612,9 @@ namespace Banshee
 				try {
 				    new LibraryTrackInfo(reader);
 				} catch(Exception e) {
-				    Core.Log.Push(LogEntryType.Warning,
+				    Core.Log.PushWarning(
 				        Catalog.GetString("Could not load track from library"),
-				        (reader["Uri"] as string) + ": " + e.Message);
+				        (reader["Uri"] as string) + ": " + e.Message, false);
 				}
 				//DateTime startStamp = DateTime.Now;
 				//RaiseTrackInfo(new LibraryTrackInfo(reader));
@@ -712,8 +708,11 @@ namespace Banshee
 				DateTime startStamp = DateTime.Now;
 				int tid = Convert.ToInt32(reader[0]);
 				TrackInfo ti = Core.Library.Tracks[tid] as TrackInfo;
-				RaiseTrackInfo(ti);
-				UpdateAverageDuration(startStamp);
+				
+				if(ti != null) {
+					RaiseTrackInfo(ti);
+					UpdateAverageDuration(startStamp);
+				}
 			}
 		}
 		
